cheesecake.subprocess.Popen

Package cheesecake :: Module subprocess :: Class Popen |
[hide private]
[frames] | no frames]

## Class Popen
source code

    object --+
             |
            Popen

Instance Methods | [hide private]
| __init__(self, args, bufsize=0, executable=None, stdin=None, stdout=None, stderr=None, preexec_fn=None, close_fds=False, shell=False, cwd=None, env=None, universal_newlines=False, startupinfo=None, creationflags=0) Create new Popen instance.
| _translate_newlines(self, data)
| _make_inheritable(self, handle) Return a duplicate of handle, which is inheritable
| _find_w9xpopen(self) Find and return absolut path to w9xpopen.exe
| _readerthread(self, fh, buffer)
| _get_handles(self, stdin, stdout, stderr) Construct and return tupel with IO objects: p2cread, p2cwrite, c2pread, c2pwrite, errread, errwrite
| _set_cloexec_flag(self, fd)
| _close_fds(self, but)
| _execute_child(self, args, executable, preexec_fn, close_fds, cwd, env, universal_newlines, startupinfo, creationflags, shell, p2cread, p2cwrite, c2pread, c2pwrite, errread, errwrite) Execute program (POSIX version)
| _handle_exitstatus(self, sts)
| poll(self) Check if child process has terminated.
| wait(self) Wait for child process to terminate.
| communicate(self, input=None) Interact with process: Send data to stdin.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, args, bufsize=0, executable=None, stdin=None, stdout=None, stderr=None, preexec_fn=None, close_fds=False, shell=False, cwd=None, env=None, universal_newlines=False, startupinfo=None, creationflags=0) (Constructor) | source code
Create new Popen instance. Overrides: object.__init__

### _translate_newlines(self, data) | source code

### _make_inheritable(self, handle) | source code
Return a duplicate of handle, which is inheritable

### _find_w9xpopen(self) | source code
Find and return absolut path to w9xpopen.exe

### _readerthread(self, fh, buffer) | source code

### _get_handles(self, stdin, stdout, stderr) | source code
Construct and return tupel with IO objects: p2cread, p2cwrite, c2pread, c2pwrite, errread, errwrite

### _set_cloexec_flag(self, fd) | source code

### _close_fds(self, but) | source code

### _execute_child(self, args, executable, preexec_fn, close_fds, cwd, env, universal_newlines, startupinfo, creationflags, shell, p2cread, p2cwrite, c2pread, c2pwrite, errread, errwrite) | source code
Execute program (POSIX version)

### _handle_exitstatus(self, sts) | source code

### poll(self) | source code
Check if child process has terminated. Returns returncode attribute.

### wait(self) | source code
Wait for child process to terminate. Returns returncode attribute.

### communicate(self, input=None) | source code
Interact with process: Send data to stdin. Read data from stdout and stderr, until end-of-file is reached. Wait for process to terminate. The optional input argument should be a string to be sent to the child process, or None, if no data should be sent to the child. communicate() returns a tuple (stdout, stderr).